@@ -1,4 +1,3 @@
-import geckodriver_autoinstaller
 import LibHanger.Library.uwLogger as Logger
 from selenium import webdriver
 from selenium.webdriver.chrome.options import Options as chromeOptions
@@ -99,10 +98,11 @@ class browserContainer:
             webDriverPath = self.getWebDriverPath(self.config.firefox)
             # WebDriverを返す
             Logger.logging.info('get webdriver - start')
-            self.wDriver = webdriver.Firefox(executable_path=webDriverPath, options=options)
+            Logger.logging.info(self.config.firefox.WebDriverLogPath)
+            #self.wDriver = webdriver.Firefox(executable_path=webDriverPath, options=options)
+            if self.config.firefox.WebDriverLogPath == '':
+                self.wDriver = webdriver.Firefox(executable_path=webDriverPath, options=options)
+            else:
+                self.wDriver = webdriver.Firefox(executable_path=webDriverPath, log_path=self.config.firefox.WebDriverLogPath, options=options)            
             Logger.logging.info('get webdriver - end')
-            #if self.config.firefox.WebDriverLogPath == '':
-            #    self.wDriver = webdriver.Firefox(executable_path=webDriverPath, options=options)
-            #else:
-            #    self.wDriver = webdriver.Firefox(executable_path=webDriverPath, log_path=self.config.firefox.WebDriverLogPath, options=options)
             return self.wDriver 
